@@ -13,19 +13,20 @@ class QDeleteNotebookView : public QvernoteWindow
     Q_OBJECT
 
 public:
-    QDeleteNotebookView(shared_ptr<QvernoteAPI> hEvernote, QWidget *parent = 0);
+    QDeleteNotebookView(QvernoteAPI* hEvernote, QWidget *parent = 0);
     ~QDeleteNotebookView();
 
     void loadNotebooksIntoView();
 
 public slots:
+	void setItemMark(QListWidgetItem *item);
    	void deleteSelectedNotebooks();
     void addSelectedCount() { m_lSelectedCount.setText(QString("%1 notebooks").arg(++m_iSelectedCount)); }
     void subSelectedCount() { m_lSelectedCount.setText(QString("%1 notebooks").arg(--m_iSelectedCount)); }
 
 private:
     Ui::QDeleteNotebookViewClass ui;
-    shared_ptr<QvernoteAPI> m_hEvernote;
+    QvernoteAPI* m_hEvernote;
     QLabel	m_lSelectedCount;
     QPushButton m_pbDeleteSelected;
     int		m_iSelectedCount;
