@@ -13,19 +13,20 @@ class QDeleteNotesView : public QvernoteWindow
     Q_OBJECT
 
 public:
-    QDeleteNotesView(shared_ptr<QvernoteAPI> hEvernote, const QString& notebookName, QWidget *parent = 0);
+    QDeleteNotesView(QvernoteAPI* hEvernote, const QString& notebookName, QWidget *parent = 0);
     ~QDeleteNotesView();
 
     void loadNotesIntoView();
 
 public slots:
+	void setItemMark(QListWidgetItem *item);
 	void deleteSelectedNotes();
     void addSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(++m_iSelectedCount)); }
     void subSelectedCount() { m_lSelectedCount.setText(QString("%1 notes").arg(--m_iSelectedCount)); }
 
 private:
     Ui::QDeleteNotesViewClass ui;
-    shared_ptr<QvernoteAPI> m_hEvernote;
+    QvernoteAPI* m_hEvernote;
     QString m_notebookName;
     QLabel	m_lSelectedCount;
     QPushButton m_pbDeleteSelected;
