@@ -12,7 +12,7 @@ class QNewNotebookDialog : public QDialog
     Q_OBJECT
 
 public:
-    QNewNotebookDialog(shared_ptr<QvernoteAPI> hEvernote, QWidget *parent = 0);
+    QNewNotebookDialog(QvernoteAPI* hEvernote, QWidget *parent = 0);
     ~QNewNotebookDialog();
 
 public slots:
@@ -23,7 +23,7 @@ signals:
 
 private:
     Ui::QNewNotebookDialogClass ui;
-    shared_ptr<QvernoteAPI> m_hEvernote;
+    QvernoteAPI* m_hEvernote;
 };
 
 #endif // QNEWNOTEBOOKDIALOG_H
