@@ -2,10 +2,13 @@
 #include "QvernoteView.h"
 #include <QWidget>
 
-QNotebookListItemWidget::QNotebookListItemWidget(Notebook& notebook, shared_ptr<QvernoteAPI> hEvernote, int noteCount, bool isDeleteMode, QWidget *parent)
+QNotebookListItemWidget::QNotebookListItemWidget(Notebook& notebook, QvernoteAPI* hEvernote, int noteCount, bool isDeleteMode, QWidget *parent)
     : QWidget(parent), m_Notebook(notebook), m_bDeleteMode(isDeleteMode), m_bItemMarked(false), m_bMouseMoved(false)
 {
 	ui.setupUi(this);
+#ifdef Q_WS_MAEMO_5
+		//setAttribute(Qt::WA_PaintOnScreen);
+#endif
 
 	if(isDeleteMode)
 		ui.lDeleteMark->setVisible(true);
@@ -17,7 +20,7 @@ QNotebookListItemWidget::QNotebookListItemWidget(Notebook& notebook, shared_ptr<
 		ui.lNotebookIcon->setPixmap(QPixmap(":/IconAdd/Star-48.png"));
 	}
 
-	ui.lNotebookName->setText(QString(m_Notebook.name.c_str()));
+	ui.lNotebookName->setText(QString::fromUtf8(m_Notebook.name.c_str()));
 
 	ui.lNotesCount->setText(QString::number((noteCount == -1)? hEvernote->getNotebookContentsCount(notebook) : noteCount, 10) + " notes");
 
@@ -26,7 +29,7 @@ QNotebookListItemWidget::QNotebookListItemWidget(Notebook& notebook, shared_ptr<
 	QString tagList;
 	for(hasNextTag = hEvernote->getFirstNotebookTag(notebook.name, tag); hasNextTag; hasNextTag = hEvernote->getNextNotebookTag(notebook.name, tag))
 	{
-		tagList += QString(tag.name.c_str()) + " ";
+		tagList += QString::fromUtf8(tag.name.c_str()) + " ";
 	}
 
 	if(tagList.size() == 0)
@@ -45,3 +48,19 @@ QNotebookListItemWidget::~QNotebookListItemWidget()
 {
 
 }
+
+void QNotebookListItemWidget::mark()
+{
+	if(m_bItemMarked)
+	{
+		m_bItemMarked = false;
+		ui.lDeleteMark->clear();
+		emit notebookUnmarked();
+	}
+	else
+	{
+		m_bItemMarked = true;
+		ui.lDeleteMark->setPixmap(QPixmap(":/IconAdd/widgets_tickmark_list.png"));
+		emit notebookMarked();
+	}
+}
