@@ -19,18 +19,25 @@ class QNotesView : public QvernoteWindow
 
 public:
 
-    QNotesView(shared_ptr<QvernoteAPI> hEvernote, const Notebook& notebook, QWidget *parent = 0);
-    QNotesView(shared_ptr<QvernoteAPI> hEvernote, QString windowTitle, QWidget *parent = 0);
+    QNotesView(QvernoteAPI* hEvernote, const Notebook& notebook, QWidget *parent = 0);
+    QNotesView(QvernoteAPI* hEvernote, QString windowTitle, QWidget *parent = 0);
     ~QNotesView();
 
-    shared_ptr<QvernoteAPI> getHandle() { return m_hEvernote; }
+    QvernoteAPI* getHandle() { return m_hEvernote; }
+    Notebook getNotebook() { return m_Notebook; }
+
+    void getNextNote(Note& nextNote);
+    void getPrevNote(Note& prevNote);
+    void clearNote(Note& m_Note);
 
 public slots:
 	void reloadNotes();
 	void loadNotesIntoView();
 	void openNewNoteWindow();
 	void openNoteEditor(QListWidgetItem *item);
-	void openNoteEditor(QNoteListItemWidget *item);
+	//void openNoteEditor(QNoteListItemWidget *item);
+	void openNoteEditor(Note&, QEnmlReader* reader = 0);
+	void openNoteViewer(QListWidgetItem *item);
 	void loadDeleteNotesView();
 	void notesViewShutdown();
 
@@ -43,7 +50,7 @@ private:
 
 private:
     Ui::QNotesViewClass ui;
-    shared_ptr<QvernoteAPI> m_hEvernote;
+    QvernoteAPI* m_hEvernote;
     vector<QNoteWidget*>	m_vNoteWidgets;
     Notebook	m_Notebook;
 };
