@@ -13,7 +13,7 @@ class QTagSelectorDialog : public QDialog
     Q_OBJECT
 
 public:
-    QTagSelectorDialog(shared_ptr<QvernoteAPI> hEvernote, const vector<string> tagNames, QWidget *parent = 0);
+    QTagSelectorDialog(QvernoteAPI* hEvernote, const Note& note, QWidget *parent = 0);
     ~QTagSelectorDialog();
 
     void loadTagsIntoView();
@@ -26,8 +26,7 @@ private:
     Ui::QTagSelectorDialogClass ui;
     vector<string> m_vTagNames;
     vector<string> tagGuids;
-    shared_ptr<QvernoteAPI> m_hEvernote;
-    QWidget* m_parent;
+    QvernoteAPI* m_hEvernote;
     QRect geom;
 };
 
