@@ -51,7 +51,8 @@ signals:
 private:
 	QvernoteSettings* settings;
 	QvernoteView* m_pWnd;
-	shared_ptr<QvernoteAPI> m_hEvernote;
+	QvernoteAPI* m_hEvernote;
+	InitThread* initThread;
 };
 
 }
