@@ -10,6 +10,18 @@
 
 #include <QSettings>
 
+#define CONFIG_VAR(_t_, _n_) 				\
+	private:								\
+	_t_ m_##_n_;							\
+	public:									\
+	_t_ get##_n_() { return m_##_n_; }			\
+	void set##_n_(_t_ _##_n_) { m_##_n_ = _##_n_; }
+
+#define LOAD_VAR(_T_, _n_, _s_, _d_) \
+		m_##_n_ = settings.value(_s_, _d_).to##_T_;
+
+#define STORE_VAR(_s_, _n_) \
+		settings.setValue(_s_, m_##_n_);
 
 class QvernoteSettings {
 public:
@@ -28,16 +40,15 @@ public:
 		return settings;
 	}
 
-public:
-	QString getUsername() { return m_qsUsername; }
-	void setUsername(QString qsUsername) { m_qsUsername = qsUsername; }
-	QString getPassword() { return m_qsPassword; }
-	void setPassword(QString qsPassword) { m_qsPassword = qsPassword; }
-	bool	getUseSsl() { return m_bSsl; }
-	void 	setUseSsl(bool enabled) { m_bSsl = enabled; }
 
-	DisplayOrientation	getDisplayOrientation() { return m_eDisplayOrientation; }
-	void	setDisplayOrientation(DisplayOrientation o) { m_eDisplayOrientation = o; }
+	CONFIG_VAR(QString, Username)
+	CONFIG_VAR(QString, Password);
+	CONFIG_VAR(bool, UseSsl);
+	CONFIG_VAR(DisplayOrientation, DisplayOrientation);
+	CONFIG_VAR(int, lastUpdateCount);
+	CONFIG_VAR(qint64, lastSyncTime)
+	CONFIG_VAR(bool, WorkOnline);
+public:
 	void 	Store();
 	void	Load();
 
@@ -47,11 +58,6 @@ private:
 	QvernoteSettings() { Load(); };
 	//QvernoteSettings(const QvernoteSettings&);
 	QvernoteSettings& operator=(const QvernoteSettings&);
-
-	QString m_qsUsername;
-	QString m_qsPassword;
-	bool	m_bSsl;
-	DisplayOrientation m_eDisplayOrientation;
 };
 
 //extern QvernoteSettings g_QvernoteSettings;
