@@ -13,7 +13,5 @@
 
 using namespace qvernote::api;
 
-typedef shared_ptr<Notebook> NotebookPtr;
-typedef shared_ptr<QListWidgetItem> QListWidgetItemPtr;
 
 #endif /* QVERNOTETYPES_H_ */
