@@ -9,6 +9,7 @@ QvernoteLoginDialog::QvernoteLoginDialog(QWidget *parent)
 	ui.setupUi(this);
 
 	QObject::connect(ui.pbSignin, SIGNAL(clicked()), this, SLOT(evernoteLogin()));
+	QObject::connect(ui.pbWorkOffline, SIGNAL(clicked()), this, SLOT(setWorkOffline()));
 }
 
 QvernoteLoginDialog::~QvernoteLoginDialog()
@@ -23,3 +24,10 @@ void QvernoteLoginDialog::evernoteLogin()
 	QvernoteSettings::Instance()->Store();
 	this->done(QDialog::Accepted);
 }
+
+void QvernoteLoginDialog::setWorkOffline()
+{
+	QvernoteSettings::Instance()->setWorkOnline(false);
+	QvernoteSettings::Instance()->Store();
+	this->done(QDialog::Accepted);
+}
